@@ -43,7 +43,9 @@ from .util import (
     get_max_retry,
     get_progress_bar,
     get_retry_sleep,
+    has_graph_easy,
     interpret_ctype,
+    is_jupyter,
     merge_ctype,
     safe_opt_num,
     ServerSideError,
@@ -621,9 +623,13 @@ class XYMEClient:
             }))["dag"]
 
     def duplicate_dag(
-            self, dag_uri: str, dest_uri: Optional[str] = None) -> str:
+            self,
+            dag_uri: str,
+            dest_uri: Optional[str] = None,
+            copy_nonowned_blobs: bool = True) -> str:
         args = {
             "dag": dag_uri,
+            "copy_nonowned_blobs": copy_nonowned_blobs,
         }
         if dest_uri is not None:
             args["dest"] = dest_uri
@@ -1230,20 +1236,68 @@ class DagHandle:
     def _pretty(
             self,
             nodes_only: bool,
-            allow_unicode: bool) -> PrettyResponse:
+            allow_unicode: bool,
+            pretty_method: Optional[str] = "accern") -> PrettyResponse:
         return cast(PrettyResponse, self._client.request_json(
             METHOD_GET, "/pretty", {
                 "dag": self.get_uri(),
                 "nodes_only": nodes_only,
                 "allow_unicode": allow_unicode,
+                "method": pretty_method,
             }))
 
     def pretty(
             self,
             nodes_only: bool = False,
-            allow_unicode: bool = True) -> str:
-        return self._pretty(
-            nodes_only=nodes_only, allow_unicode=allow_unicode)["pretty"]
+            allow_unicode: bool = True,
+            pretty_method: Optional[str] = "accern",
+            dot_output: Optional[str] = "svg",
+            display: bool = True) -> Optional[str]:
+
+        def render(value: str) -> Optional[str]:
+            if display:
+                print(value)
+                return None
+            return value
+
+        graph_str = self._pretty(
+            nodes_only=nodes_only,
+            allow_unicode=allow_unicode,
+            pretty_method=pretty_method)["pretty"]
+        if pretty_method == "accern":
+            return render(graph_str)
+        if pretty_method == "dot":
+            from graphviz import Source
+
+            graph = Source(graph_str)
+            if dot_output == "dot":
+                return render(graph_str)
+            if dot_output == "svg":
+                svg_str = graph.pipe(format="svg")
+                if display:
+                    if not is_jupyter():
+                        print("Warning: Ipython instance not found.")
+                        print(svg_str)
+                    else:
+                        from IPython.display import display as idisplay
+                        from IPython.display import SVG
+                        idisplay(SVG(svg_str))
+                    return None
+                return svg_str
+            if dot_output == "ascii":
+                if not has_graph_easy():
+                    return render(graph_str)
+
+                import subprocess
+                cmd = ["echo", graph_str]
+                p1 = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+                p2 = subprocess.check_output(
+                    ["graph-easy"], stdin=p1.stdout)
+                res = p2.decode("utf-8")
+                return render(res)
+            raise ValueError(
+                "invalid dot output option, use svg, ascii or dot")
+        raise ValueError("invalid dot pretty_method, use accern or dot")
 
     def pretty_obj(
             self,
